@@ -521,8 +521,7 @@ impl<'a> AsRow<'a> for ContentListing {
                 ColumnId::PhysicalPath => TextCell::new(&self.details.storage_path),
                 ColumnId::Digest => TextCell::new(format!(
                     "{}:{}",
-                    self.details.digest_algorithm,
-                    self.details.digest
+                    self.details.digest_algorithm, self.details.digest
                 )),
                 _ => TextCell::blank(),
             };
