@@ -216,7 +216,7 @@ impl VersionNum {
     pub fn next(&self) -> Result<VersionNum> {
         let max = match self.width {
             0 => u32::MAX,
-            _ => u32::pow(10, self.width -1) - 1,
+            _ => u32::pow(10, self.width - 1) - 1,
         };
 
         if self.number + 1 > max as u32 {
@@ -1178,7 +1178,7 @@ fn join(use_backslashes: bool, parent: &str, child: &str) -> String {
 /// Changes `/` to `\` on Windows
 fn convert_path_separator(use_backslashes: bool, path: String) -> String {
     if use_backslashes && path::MAIN_SEPARATOR == '\\' {
-        return path.replace("/", "\\");
+        return path.replace('/', "\\");
     }
     path
 }
